# COMPARING QUANTITIES

>A PYPY Package that can be used to find Discount,Cost price, Compound Interest annually and half-yearly,
Selling price, Profit,Loss,Net price, Bill amount,Value added tax,Simple interest and Total amount.

## INSTALLATION

###### Run the following to install:

cmd pip install Comparing-Quantities

### CONTRIBUTOR

_KARTHIK P_ 

### MENTOR 
       
_VIDHYA LAKSHMI_ 